Egg class

Constructors

Egg({required Map<String, dynamic> data})

Properties

data Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOrUpdateSubEgg(String subEggId, Map<String, dynamic> subEggData) → void
delete(String directoryPath) → void
getAllSubEggs() Map<String, dynamic>
getSubEgg(String subEggId) Map<String, dynamic>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSubEgg(String subEggId) → void
save(String directoryPath) → void
toString() String
A string representation of this object.
inherited
update(String directoryPath, Map<String, dynamic> newData) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited